#
# spec file for package python-jaraco.stream
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   jaraco.stream
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-jaraco.stream
Version:        3.0.0
Release:        bp153.1.19
Summary:        Routines for dealing with data streams
License:        MIT
URL:            https://github.com/jaraco/jaraco.stream
Source:         https://files.pythonhosted.org/packages/source/j/%{_name}/%{_name}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jaraco.base >= 6.1
Requires:       python-more-itertools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pytest}
# /SECTION
# SECTION documentation requirements
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module jaraco.packaging >= 6.1}
BuildRequires:  %{python_module pylons-sphinx-themes}
BuildRequires:  %{python_module rst.linker >= 1.9}
# /SECTION
%python_subpackages

%description
Routines for handling streaming data, including a set of generators
for loading gzip data on the fly.

%package     -n %{name}-doc
Summary:        Documentation files for %{name}
Provides:       %{python_module jaraco.stream-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n %{_name}-%{version}
sed -i 's/--flake8//' pytest.ini
sed -i 's/--black --cov//' pytest.ini
rm -rf jaraco.stream.egg-info

%build
%python_build
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
%python_install
# We will package the namespace __init__.py separately
%{python_expand rm %{buildroot}%{$python_sitelib}/jaraco/__init__.py*
rm -rf %{buildroot}%{$python_sitelib}/jaraco/__pycache__/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%{python_sitelib}/jaraco.stream-%{version}-py*.egg-info
%{python_sitelib}/jaraco/stream/

%files -n %{name}-doc
%doc build/sphinx/html

%changelog
* Mon Mar  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.0
  * Drop support for Python 3.5 and earlier (including Python 2).
  * Adopt black for code style and other updates from jaraco/skeleton.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Remove bcond_with test, allowing tests suite to run
- Remove undesirable build dependencies pytest-flake8 and pytest-runner
- Add missing runtime dependency on six
- Add explicit build dependency on python-six
- Update to v2.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace.
* Sat Jul 28 2018 jengelh@inai.de
- Fix RPM groups.
* Tue Jun 26 2018 mcepl@suse.com
- Upgrade to 1.2:
  Added ``jaraco.stream.Tee`` from jaraco.util 11
- Clean up SPEC to full singlespec.
* Mon Nov 13 2017 toddrme2178@gmail.com
- Properly handle namespace package structure.
  This guarantees the module is importable.
* Tue Jul  4 2017 aloisio@gmx.com
- Update to version 1.1.2
  * Refresh packaging.
- Create -doc package
- Converted to single-spec
* Sat Jul 30 2016 sor.alexei@meowr.ru
- Initial package.
